#
# spec file for package ruby-common
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


### seems that %{_rpmmacrodir} is not known on SLE 12 / Leap 42
%if 0%{?suse_version} == 1315
%define _rpmmacrodir /etc/rpm
%endif

Name:           ruby-common
Version:        3.2.1
Release:        7.2
# ruby-macros and ruby-common version
%define rpm_macros_version 5
%if 0
%bcond_with    ship_gemrc
%else
%bcond_without ship_gemrc
%endif
Source1:        gem_build_cleanup
Source2:        gemrc
Source4:        rubygems.attr
Source5:        rubygemsdeps.rb
Source6:        gem_install.sh
Source7:        generate_buildrequires.sh
Source8:        ruby-common.macros
Source9:        ruby.rpm-macros
Source10:       gem_packages.sh
Source11:       gem_packages.spec.erb
Source12:       ruby-find-versioned
Source13:       gemfile.attr
Source14:       gemfile.rb
Source15:       rails.macros
Source16:       g2r
Source17:       rubygems_bundled.attr
Source18:       irp.rb
Source19:       bundler-dumpdeps
Summary:        Collection of scripts and macros for ruby packaging
License:        MIT
Group:          Development/Languages/Ruby
URL:            https://github.com/openSUSE/ruby-packaging/
Requires:       /usr/bin/getopt
Requires:       rubygem(gem2rpm)
Recommends:     rubygem(%{rb_default_ruby_abi}:gem2rpm)
Requires:       fdupes
BuildArch:      noarch
Provides:       ruby-macros = %{rpm_macros_version}
%if 0%{?suse_version} < 1140 && 0%{?suse_version} > 1110
# we need a patched rpm
Requires:       rpm-with-ruby-provide-hook
%endif
# for getopt
Requires:       util-linux

%description
This package is needed for (generated) ruby gems. It provides hooks for
automatic rpm provides and requires and macros that gem2rpm uses.

%package rails
Requires:       rubygem(bundler)
Recommends:     rubygem(%{rb_default_ruby_abi}:bundler)
Requires:       %{name} = %{version}-%{release}

Summary:        Rails packaging support
Group:          Development/Languages/Ruby

%description rails
This package is needed for (generated) ruby gems. It provides hooks for
automatic rpm provides and requires and macros that gem2rpm uses.

Rails packaging support files.

%package  -n ruby-packaging-helpers
Requires:       %{name} = %{version}-%{release}

Summary:        Ruby packaging helpers
Group:          Development/Languages/Ruby

%description  -n ruby-packaging-helpers
This package is needed for (generated) ruby gems. It provides hooks for
automatic rpm provides and requires and macros that gem2rpm uses.

Some helper tools for packaging rubygems and rails apps.

%prep

%build

%install
# we need to make sure it overwrites older macro versions and rpm sorts alphabetically
%if %{with ship_gemrc}
install -D -m 0644 %{S:2}  %{buildroot}/etc/gemrc
%endif
install -D -m 0644 %{S:8}  %{buildroot}%{_rpmmacrodir}/macros.ruby-common
install -D -m 0644 %{S:9}  %{buildroot}%{_rpmmacrodir}/macros.suse-ruby
install -D -m 0644 %{S:4}  %{buildroot}/usr/lib/rpm/fileattrs/rubygems.attr
install -D -m 0755 %{S:5}  %{buildroot}/usr/lib/rpm/rubygemsdeps.rb
install -D -m 0755 %{S:6}  %{buildroot}/usr/lib/rpm/gem_install.sh
install -D -m 0755 %{S:1}  %{buildroot}/usr/lib/rpm/gem_build_cleanup.sh
install -D -m 0755 %{S:7}  %{buildroot}/usr/lib/rpm/generate_buildrequires.sh
install -D -m 0755 %{S:10} %{buildroot}/usr/lib/rpm/gem_packages.sh
install -D -m 0644 %{S:11} %{buildroot}/usr/lib/rpm/gem_packages.template
install -D -m 0755 %{S:12} %{buildroot}%{_bindir}/ruby-find-versioned
install -D -m 0644 %{S:13} %{buildroot}/usr/lib/rpm/fileattrs/gemfile.attr
install -D -m 0755 %{S:14} %{buildroot}/usr/lib/rpm/gemfile.rb
install -D -m 0644 %{S:15} %{buildroot}%{_rpmmacrodir}/macros.rails
install -D -m 0755 %{S:16} %{buildroot}%{_bindir}/g2r
install -D -m 0755 %{S:18} %{buildroot}%{_bindir}/irp
install -D -m 0755 %{S:19} %{buildroot}%{_bindir}/bundler-dumpdeps
install -D -m 0644 %{S:17} %{buildroot}/usr/lib/rpm/fileattrs/rubygems_bundled.attr

%files
%if %{with ship_gemrc}
%config /etc/gemrc
%endif
%{_rpmmacrodir}/macros.*ruby*
%dir /usr/lib/rpm/fileattrs
/usr/lib/rpm/fileattrs/rubygems.attr
/usr/lib/rpm/fileattrs/rubygems_bundled.attr
/usr/lib/rpm/rubygemsdeps.rb
/usr/lib/rpm/gem_install.sh
/usr/lib/rpm/gem_build_cleanup.sh
/usr/lib/rpm/generate_buildrequires.sh
/usr/lib/rpm/gem_packages.*
%{_bindir}/ruby-find-versioned
%{_bindir}/g2r

%files -n ruby-packaging-helpers
%{_bindir}/irp
%{_bindir}/bundler-dumpdeps

%files rails
%{_rpmmacrodir}/macros.rails
/usr/lib/rpm/fileattrs/gemfile.attr
/usr/lib/rpm/gemfile.rb

%changelog
* Wed Jan 22 2025 Marcus Rueckert <mrueckert@suse.de>
- do not generate unversioned conflicts
* Tue Oct  8 2024 Marcus Rueckert <mrueckert@suse.de>
- update gem_packages.spec.erb by syncing with gem2rpm
  - drop group tag
  - only emit manual comments if we actually put out content
  - mark docs explicitely with the %%doc tag
  - stop using deprecated PreReq for update-alternatives
* Sat Sep 28 2024 Marcus Rueckert <mrueckert@suse.de>
- update gem_packages.spec.erb:
  dont strip the newline at the end of main:filelist output
* Fri Jun  7 2024 Marcus Rueckert <mrueckert@suse.de>
- refactor the jemalloc requires code so that it can accomodate
  more feature flags
- add requires for yjit enabled ruby
* Thu Nov 16 2023 Marcus Rueckert <mrueckert@suse.de>
- gem_cleanup macro: yet another place which got hit by ruby 3.3
  replace `gem env gemdir` with
  `ruby -r rubygems -e 'puts Gem.default_dir'`
* Tue Nov 14 2023 Marcus Rueckert <mrueckert@suse.de>
- Fix for the previous change. we need to set the GEM_HOME before
  even wrapping into the re-exec with ruby.
* Mon Nov 13 2023 Marcus Rueckert <mrueckert@suse.de>
- add workaround for https://github.com/rubygems/rubygems/commit/64273fd7e3
  for now we will always set GEM_HOME to ensure that this new logic
  does not break our paths
* Sat Nov  4 2023 Marcus Rueckert <mrueckert@suse.de>
- ensure that gems built against an jemalloc enabled ruby
  also pulls a ruby version that is built with jemalloc
* Fri May 12 2023 Marcus Rueckert <mrueckert@suse.de>
- bump the version so we can require the new version to make it
  easier to depend on the new functionality
* Fri May 12 2023 Marcus Rueckert <mrueckert@suse.de>
- Support runtime dependencies for the generated subpackages:
  syntax:
  Requires: rubygem(gemname)
  Recommends: rubygem(gemname:x) >= x.y
  This will be transformed into
  Requires: rubygem(ruby:<rubyabi>:gemname)
  Recommends: rubygem(ruby:<rubyabi>:gemname:x) >= x.y
  That way we ensure that every package only requires rubygems for
  the current ruby version.
* Sun May  7 2023 Jan Engelhardt <jengelh@inai.de>
- Remove old specfile constructs
* Sun May  7 2023 Marcus Rueckert <mrueckert@suse.de>
- cleanup irp code
  - unify error handling using the exit_with_error function
  - ensure we add generated files
  - checkin the newly created package
* Tue Mar 21 2023 Marcus Rueckert <mrueckert@suse.de>
- move new tools into a subpackage ruby-packaging-helpers to avoid
  dependency to /usr/bin/ruby
* Tue Mar 21 2023 Marcus Rueckert <mrueckert@suse.de>
- Add 2 new utilities
  - irp aka initialize ruby package
    does exactly what the name says. does all the work to
    initialize a new ruby package
  - bundler-dumpdeps: script to generate BR/Requires based on a
    Gemfile.
* Thu Feb  9 2023 Marcus Rueckert <mrueckert@suse.de>
- do not rely on file dependencies for getopt
* Thu Nov 17 2022 Marcus Rueckert <mrueckert@suse.de>
- actually bump the version so we can require the newer version for
  ruby3.2
* Thu Nov 17 2022 Marcus Rueckert <mrueckert@suse.de>
- replace `File.exists?` with `File.exist?` as the `File.exists?`
  is no longer supported in 3.2
* Sat Aug 20 2022 Marcus Rueckert <mrueckert@suse.de>
- in the dependency generator for Gemfile.lock we now skip vendored
  deps
* Mon Jun 13 2022 Marcus Rueckert <mrueckert@suse.de>
- make %%gem_unpack and %%gem_build work when the default system ruby
  is not installed:
  both macros now use the %%{gem_binary} define and we have a common
  macro %%{set_gem_binary} to set this variable. the set macro will
  use the ruby-find-versioned to find a versioned version of gem.
* Wed Feb 23 2022 Dirk Müller <dmueller@suse.com>
- avoid bashism in gem_build_cleanup
* Tue Aug 24 2021 Stephan Kulow <coolo@suse.com>
- Do not create links in /etc/alternatives at all - they are ghosts
  and rpm database will only be confused if we have some wrong
  information about them (the link target is defined at runtime)
  This aligns with ruby2.7 package to avoid file conflicts about
  bundler and other built in gems
* Thu Jul  8 2021 Stephan Kulow <coolo@suse.com>
- Fix the links in /etc/alternatives not to point to themselves
* Tue Jan 26 2021 Marcus Rueckert <mrueckert@suse.de>
- cleanup the .gem.* dirs that rubygems creates on 3.0
  (boo#1180528)
* Mon Jan 25 2021 Marcus Rueckert <mrueckert@suse.de>
- add support to package rubygems plugin dirs
  as the file is conflicting you can only have one version of the
  same gem installed if it provides a rubygems plugin. at least for
  now
* Mon Sep  9 2019 chris@computersalat.de
- fix build for SLE 12 / Leap 42
  * add define _rpmmacrodir /etc/rpm
* Fri May 10 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Move RPM macros to %%_rpmmacrodir.
* Sun May  5 2019 Marcus Rueckert <mrueckert@suse.de>
- disable docs and testsuite packaging by default
- support --no-document option
* Thu Feb  7 2019 Marcus Rueckert <mrueckert@suse.de>
- rails.macros: add macro to fix ruby shebang line
* Thu Feb  7 2019 Marcus Rueckert <mrueckert@suse.de>
- rails.macros: always use ./bin/* stubs for calling binaries
* Wed Jan 30 2019 Marcus Rueckert <mrueckert@suse.de>
- do not try to delete git files in the rails macros
* Fri Dec 21 2018 Marcus Rueckert <mrueckert@suse.de>
- --no-rdoc/--no-ri are obsolete in, if we get it passed in convert
  them to --no-document
* Wed Jun  6 2018 mrueckert@suse.de
- rename the gem_packages template from opensuse.spec.erb to
  gem_packages.spec.erb
- add support for binary_map flag in gem2rpm.yml
  - This can be used to rename the _unversioned_ symlink of the
    binaries in /usr/bin/ to avoid conflicts with other packages
- gem_packages.spec.erb: sync with file in gem2rpm
* Wed Jan 24 2018 lnussel@suse.de
- generate bundled(rubygem($name)) = $version provides for bundled
  gems in the vendor directory.
* Tue Dec 12 2017 mrueckert@suse.de
- switch requires of the autogenerated subpackages from
  rb_suffix-rubygem-gemname = version to
  rubygem(rb_abi:gemname) = version
* Thu Nov 30 2017 mrueckert@suse.de
- split our the rails part
* Thu Nov 30 2017 mrueckert@suse.de
- we need bundler now. given ruby 2.5 will have it intree anyway,
  this soon wont be a big burden.
* Thu Nov 30 2017 mrueckert@suse.de
- add support to generate requires from Gemfile.lock
* Mon Aug  7 2017 mrueckert@suse.de
- package the buildinfo dir
- allow passing options to extconf.rb
* Tue Jun 13 2017 bwiedemann@suse.com
- Call fdupes -o name to make sure we always create symlinks
  in the same direction to make builds reproducible
* Tue Mar  1 2016 mrueckert@suse.de
- Since rubygems 2.5.0 the default version in the gem bin stub
  changed from '>= 0' to '>= 0.a'. This was done to allow
  prerelease versions. Our patching script didn't take the '.a'
  into account and generated version fields like '= 0.10.1.a'
  instead of the expected '= 0.10.1'. This fix accounts for the
  '.a'.
* Thu Jun 11 2015 lnussel@suse.de
- help the solver to pick the right gem2rpm for the default ruby
  version (bnc#934328)
* Sat May  2 2015 mrueckert@suse.de
- Fix patching of the shebang line
* Thu Apr 16 2015 mrueckert@suse.de
- The script sometimes returned from gem install already although
  the install wasn't finished yet. This broke e.g. the binary
  rename part.
* Fri Mar 13 2015 mrueckert@suse.de
- Fail early if gem install fails
  This avoids confusing error messages at the end of the build.
* Fri Mar 13 2015 mrueckert@suse.de
- More fixes for ruby 1.8
* Fri Mar 13 2015 mrueckert@suse.de
- Ruby 1.8 insists on the () for the parameter
* Fri Mar 13 2015 mrueckert@suse.de
- Cleaner solution for the extensions doc dir
  The other solution was also failing on 1.8
* Fri Mar 13 2015 mrueckert@suse.de
- Forgot another option for forwarding
* Fri Mar 13 2015 mrueckert@suse.de
- Do not overwrite options.otheropts
* Fri Mar 13 2015 mrueckert@suse.de
- Fixed forwarding of options to gem install
* Fri Mar 13 2015 mrueckert@suse.de
- Only use the extensions doc dir on MRI 2.1.x
* Fri Mar 13 2015 mrueckert@suse.de
- Fix the ruby suffix for distributions before 13.2
- Do not fail with --gem-binary
* Fri Mar 13 2015 mrueckert@suse.de
- switch to ruby version of gem_install.sh
- added ruby-find-versioned to make it easier to find versioned
  binaries.
  - all for loops in the shell scripts and macros are now using
    this script
* Thu Mar 12 2015 mrueckert@suse.de
- call ruby with -x from shell wrappers otherwise we run into an
  endless loop
* Thu Jan 15 2015 dmueller@suse.com
- rubygemsdeps.rb: add shell-launcher to avoid dependency on
  a fixed ruby version
* Tue Jan 13 2015 dmueller@suse.com
- gem_install.sh: fix ruby shebang patching
* Sat Nov 15 2014 Led <ledest@gmail.com>
- fix bashisms in generate_buildrequires.sh script
* Tue Oct 21 2014 mrueckert@suse.de
- restore changes lost by the previous change
  - load rbconfigpackagingsupport if available and fail gracefully
    if not.
  - dont use not() it breaks the build on 1.8
  - remove requires onto the ruby version
* Sat Oct 18 2014 coolo@suse.com
- update gem_packages template from git
* Mon Sep 29 2014 mrueckert@suse.de
- ignore any files we find in */.gem/*. in some versions of
  rubygems, gems that are installed are also copied to ~/.gem/.
* Fri Sep 26 2014 mrueckert@suse.de
- we dont always have /usr/bin/ruby, use perl for patching the
  version in the bin wrapper. also replaced the sed for patching
  the shebang line.
- fixed a bad bug in the shebang line. we had an additional "."
  there.
* Fri Sep 26 2014 mrueckert@suse.de
- install gemrc on all distros
* Fri Sep 26 2014 mrueckert@suse.de
- dont delete .a files. there are actually gems where we need them
  like rubygem-libv8 for rubygem-therubyracer
* Tue Sep 23 2014 mrueckert@suse.de
- fix the case where we dont symlink the binaries.
* Fri Sep 19 2014 mrueckert@suse.de
- gem_cleanup macro was missed when updating for old ruby versions.
* Fri Sep 19 2014 mrueckert@suse.de
- switch from "ruby -rrubygems -e
  'print Gem::Specification.new.base_dir'"
  to "gem env gemdir"
* Fri Sep 19 2014 mrueckert@suse.de
- gem_build_cleanup: also delete static library files
* Wed Sep 17 2014 mrueckert@suse.de
- ruby 1.8 support:
  - gem_packages.sh: change to /usr/src/packages when
    /home/abuild/rpmbuild doesn't exist.
  - gem_packages template:
  - require rbconfigpackagingsupport to fix the ruby_install_name
    dependent variables. we do that for all distros but catch the
    LoadError and continue.
  - and dont use not(), we need to use "!" instead.
* Wed Sep 17 2014 mrueckert@suse.de
- our sle 11 sp3 rpm does provide the support for the automatic
  rubygems dependency but does not provide
  rpm-with-ruby-provide-hook. guard the requires with > 1110
* Wed Sep 17 2014 mrueckert@suse.de
- remove the handling of spec.required_ruby_version here. this
  should be handled in rubygemsdeps.rb if at all. we already guard
  for this in the buildrequires and then have a requires via the
  $interpreter(abi) requires onto the newer version.
* Wed Sep 17 2014 mrueckert@suse.de
- invert the logic. only stop shipping /etc/gemrc on 12.3 and 13.1
* Wed Sep 17 2014 mrueckert@suse.de
- gem_packages template:
  Dont allow an suffix with just a plain number. prefix it with
  ruby.
* Wed Sep 17 2014 mrueckert@suse.de
- gem_packages also need the rewrite that rewrites a number only
  suffix into .ruby<numbersuffix>
* Wed Sep 17 2014 mrueckert@suse.de
- made the matcher for older versions more strict so we dont pick
  up gem2rpm.
* Wed Sep 17 2014 mrueckert@suse.de
- also add support for older versioning in gem_packages.sh
* Wed Sep 17 2014 mrueckert@suse.de
- added support for the versioning scheme in 13.1 and older
- dont ship gemrc on 13.1
* Mon Sep 15 2014 mrueckert@suse.de
- the ruby(abi) = $interpreter:$abiversion was not a good idea. rpm
  treats the $interpreter part as epoch. instead we use now:
  $interpreter(abi) = $abiversion
  For MRI it means we are basically back to ruby(abi).
  Examples for alternative ruby interpreters are rubinius(abi) and
  jruby(abi) (bnc#896658)
* Mon Sep  8 2014 mrueckert@suse.de
- disable extensions doc dir on rubinius
* Mon Sep  8 2014 mrueckert@suse.de
- workaround https://github.com/rubinius/rubinius/issues/2732
  for UTF8 locale in gem_packages.sh
* Thu Sep  4 2014 mrueckert@suse.de
- we actually need the splitted version in any case. uncomment it
  again
* Wed Sep  3 2014 mrueckert@suse.de
- pass the ruby abi as hash containing :interpreter, :version,
  :abi as keys. that way we have the full new string but also the
  version for the 1.8 support
* Wed Sep  3 2014 mrueckert@suse.de
- rubygemsdeps.rb:
  - make the provides/requires also include the ruby interpreter
  - no longer emit the old package name style provides
- rubygems.attr:
  - make the path a bit more relaxed so we can match other ruby
    interpreter too
* Wed Jul 16 2014 mrueckert@suse.de
- added ruby-common.macros:
  Holds the common macros for the rpm macro based buildrequires.
- merged ruby.macros into ruby.rpm-macros:
  the later file now carries the rb_* and gem_* macros
* Tue Jul 15 2014 mrueckert@suse.de
- ruby.macros: drop the duplicate gem macros
* Tue Jul 15 2014 mrueckert@suse.de
- fix small typo in opensuse.spec.erb which broke the formatting.
* Tue Jul 15 2014 mrueckert@suse.de
- no longer require ruby(-devel). ruby-common is required by
  rubyX.Y so we should always be installed and this breaks a small
  loop
- opensuse.spec.erb
  - no longer require the plain ruby package but the versioned
    named
  - handle disable_doc and no longer build subpackages for rdoc
    documentation in that case.
* Fri Jul 11 2014 mrueckert@suse.de
- remove the set -x from gem_install
- moved set -x in gem_packages to the interesting part only
- the gem packages template only handles custom_pkgs_ruby_versioned
* Thu Jul 10 2014 mrueckert@suse.de
- make use of config file support in gem2rpm (gem2rpm.yml)
  - gem_install.sh
  - drop gem-filelist-append and gem-custom-packages params
  - removed unneeded "-" when appending gem_version_suffix
  - gem_packages.sh
  - drop gem-suffix, gem-filelist-append and gem-custom-packages
    params
  - added gem2rpm-config param
  - added code to find gem2rpm.yml in RPM_SOURCE_DIR
  - opensuse.spec.erb
  - no longer get variables from the env. this is handled by the
    config file now
  - implemented all the gem2rpm.yml hooks
  - ruby.rpm-macros
  - removed usage of dropped cmdline arguments
  - pass mod_version_suffix to gem_install.sh
* Thu Jul 10 2014 mrueckert@suse.de
- pass the output of gem_packages through %%{expand} so macros and
  so on work.
* Wed Jun 25 2014 mrueckert@suse.de
- in the past we had a few spec files were we manually patched the
  version in the binary wrapper from ">= 0" to "= %%version"
  do this in gem install now.
* Wed Jun 25 2014 mrueckert@suse.de
- do not have the expanded version of rubygem(gem2rpm) in the spec
  file. moved to project config.
* Wed Jun 25 2014 mrueckert@suse.de
- adapt the symlink handling:
  We will us the versioned names in /etc/alternatives now instead of
  mapping everything to /etc/alternatives/$binaryname.
  That means we will get:
  /usr/bin/$binaryname$rubysuffix  /etc/alternatives/$binaryname$rubysuffix
  /usr/bin/$binaryname-$gemversion /etc/alternatives/$binaryname-$gemversion
  /usr/bin/$binaryname             /etc/alternatives/$binaryname
  The subpackage template and gem_install.sh script got adopted to
  this.
- no longer patch files in $buildroot/usr/bin/.
  If we patch files there, we break the binaries for older ruby
  versions. we limit the search path to the gem dir.
- loop over each gem directory in gem_cleanup macro. so far we only
  cleaned up the gems for the default ruby
- add requires for fdupes. one of the macro is using it.
- bump rpm_macros_version to 5
* Wed Jun 25 2014 mrueckert@suse.de
- really make gem_install.sh work with more than one ruby version
  - use pushd/popd instead of cd when creating the symlinks
  - only create the generic symlinks if they dont exists already
* Mon Jun 23 2014 mrueckert@suse.de
- added 2 new options to gem_packages.sh
  - --gem-filelist-append="arg"
    This can be either a string or a filename to a filelist that
    will be appended to the versioned main package
  - --gem-custom-packages="name|filelist[|preamble[|description]]"
    filelist, preamble and description can be either filenames or
    the actual value.
  to use both from the spec file you need to use
  %%define gem_custome_packages ...
  %%define gem_filelist_append ...
  important if you use the filename option, you need to call the
  tools to generate the files with %%(....) so the files are
  actually available at the time when gem_packages is run. The tool
  is called at the very beginning of the build, even before %%prep.
- update the gem_packages template to handle those 2 options and
  also the --gem-suffix option.
  they are all passed via environment variables for now.
- bumped the rpm_macro_version to 4
* Thu Jun 19 2014 mrueckert@suse.de
- as it turns out gem_build_complete_path files are important.
  Do not delete them in the cleanup script.
* Wed Jun 18 2014 mrueckert@suse.de
- added gem_packages macro and implementation
- fix shebang patching in gem_install
* Wed Jun 18 2014 mrueckert@suse.de
- if we dont use --symlink-binaries, let's undo the
  - -format-executable, that we we break less packages
* Wed Jun 18 2014 mrueckert@suse.de
- added --symlink-binaries option to gem_install.sh:
  instead of breaking all the existing rubygem packages lets pass
  this option until we have all packages fixed and we can turn it
  on by default
* Wed Jun 18 2014 mrueckert@suse.de
- a lot of additions to the gem_install.sh
  * --doc-files="..." - which files relatively to the installed gem
    directory should be symlinked to /usr/share/doc/packages/rpmname
  - > you can move the manual linking of documentation files to
    the --doc-files option
  * --gemsuffix="suffix" - if you need more than one version of the
    same gem.
  * all the symlinks for the different versioned files are not
    generated following the same rules that the template is using.
  - > you can remove the manual code from the spec file
- enable format-executable again in the global gemrc
- pass gem name and version from the %%gem_install macro to the
  gem_install.sh, avoids parsing the gem file name in the shell
  script.
* Tue Jun 17 2014 mrueckert@suse.de
- added opensuse.spec.erb this gem2rpm template should be later
  used by the gem_packages macro to create the needed file and
  package sections
- make gem_install.sh loop over all /usr/bin/gem[1-9]*
* Tue Jun 17 2014 mrueckert@suse.de
- added more patterns to the cleanup script for ruby 2.1
  - gem.build_complete
  - page\*.ri
* Sun Jun 15 2014 mrueckert@suse.de
- installed the wrong file as gemrc
* Sat Jun 14 2014 mrueckert@suse.de
- merge files from the ruby 2.1 package
- moved gemrc from the ruby wrapper package
* Tue Apr 29 2014 aspiers@suse.com
- eliminate "useless-provides rubygem-foo" rpmlint warning for
  every gem: "Provides: rubygem-foo = 1.2.3" is not required
  because rpm implicitly adds "Provides: rubygem-foo = 1.2.3-4"
* Tue Feb  4 2014 kkaempf@suse.com
- make %%gem_extensions and %%gem_doc_ext not fail on Ruby < 2.1
* Sun Jan 12 2014 coolo@suse.com
- remove 2.0 and 1.9 as binary suffix
* Sun Jan 12 2014 coolo@suse.com
- increase the version and make gem_base generic
* Mon Jan  6 2014 coolo@suse.com
- switch to 2.1 as default
* Thu Sep 12 2013 mrueckert@suse.de
- fixed bootstrap problem by ignoring ruby-common at build time
* Sat Sep  7 2013 coolo@suse.com
- do no longer buildrequire rubygems_with_buildroot_patch, that's
  history long enough - ruby-devel will do
* Thu Jun  6 2013 coolo@suse.com
- fixed ~> 3.4 to actually require 3
* Mon Apr 29 2013 coolo@suse.com
- switch to ruby 2.0 as default
* Sun Apr 14 2013 coolo@suse.com
- fix permissions
* Tue Apr  9 2013 coolo@suse.com
- do not remove ext completely, e.g. passenger extensions require
  some files from there
* Sat Mar 23 2013 coolo@suse.com
- remove ext too, it only causes problems - as far as I can see
* Fri Mar  8 2013 rhafer@suse.com
- Some enhancements to rubygemsdeps.rb:
  - Add --file-match option to rubygemsdeps.rb to allow
    specifying and alternate regex to match the input files
    against. This is useful to generate dependencies from gemspec
    files which do not endup being installed in the default
    locations
  - Default rubyabi to a non-nil value (basically the version of
    of the ruby interpreter that runs the script)
* Wed Jan  9 2013 aspiers@suse.com
- Fix it to work even if all-good has just been created locally
  via mkpac and doesn't exist server-side yet.
- Improve support for running within a branch of the original
  project.  This allows submitreqs which change all-good.spec.
* Tue Jan  8 2013 idonmez@suse.com
- Bump version to 2.0 so we don't get a version downgrade when
  updating from 12.2
* Fri Dec 28 2012 coolo@suse.com
- always provide the full version string as people use
  ~> 1.2 even if the version is 1.2
  The old logic assumed people would always require one digit
  less than the actual version
* Wed Dec 19 2012 aspiers@suse.com
- Import an enhanced version of d:l:r:e/all-good/update-sources.sh
  which can be reused for any project, and allows more thorough
  handling of BuildRequires from different repository / arch
  combinations.
* Tue Dec  4 2012 nkrinner@suse.com
- Bring back fix from submit request 140568 (Revision 23):
  Fix gemspec filtering on SLE_11_SP2:
    + Only gemspec files resulting of the built gem matter, not other
    gemspec found in-tree
    + Newer RPM uses rubygem.attr, which filters correctly
* Fri Nov 30 2012 coolo@suse.com
- require rubygems for old ruby versions
- strip trailing .0 for ~> operator
* Fri Nov 23 2012 aspiers@suse.com
- Add -g option to rubygemsdeps.rb to allow preview / review
  of automatically generated dependencies from:
    + gemspecs in packages which have already been installed
    + gems/gemspecs which have not yet been packaged
  This is useful for learning / debugging the dependency generator.
* Wed Nov  7 2012 saschpe@suse.de
- Fix gemspec filtering on SLE_11_SP2:
  + Only gemspec files resulting of the built gem matter, not other
    gemspec found in-tree
  + Newer RPM uses rubygem.attr, which filters correctly
* Mon Nov  5 2012 coolo@suse.com
- fix build on fedora
* Thu Aug  2 2012 coolo@suse.com
- "~> 2" doesn't have any meaning, but we still need to handle it
* Wed Aug  1 2012 coolo@suse.com
- fixing the pessimistic operator
* Mon Jul 30 2012 coolo@suse.com
- replace all */ruby with /usr/bin/ruby
* Fri Jul 27 2012 coolo@suse.com
- replace /usr/local/bin/ruby with /usr/bin/ruby - a very often mistake
* Thu Jul 26 2012 coolo@suse.com
- fix ruby provides/requires with ruby 1.8
* Thu Jul 26 2012 coolo@suse.com
- old gems do not have a gem unpack --spec, so use gem specification
* Thu Jul 26 2012 coolo@suse.com
- catch unspecified gem_binary
* Thu Jul 26 2012 coolo@suse.com
- split from ruby package for easier backporting
